ChatMessageReaction class
Constructors
- ChatMessageReaction({String? ChatMessageReactionId, String? ChatMessageId, String? UserId, String? Emoji, String? ReactedAt})
-
ChatMessageReaction.fromJson(Map<
String, dynamic> json) -
factory
Properties
- ChatMessageId ↔ String?
-
getter/setter pair
- ChatMessageReactionId ↔ String?
-
getter/setter pair
- Emoji ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ReactedAt ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- UserId ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited